@@ -4,6 +4,7 @@ from redis_data_structures.bloom_filter import BloomFilter
 def main():
     # Initialize a Bloom filter with custom parameters
     bloom = BloomFilter(
+        key="email_blacklist",
         expected_elements=1000,  # Expect to store ~1000 elements
         false_positive_rate=0.01,  # 1% false positive rate
         host="localhost",
@@ -11,15 +12,12 @@ def main():
         db=0,
     )
 
-    # Key for our Bloom filter in Redis
-    filter_key = "email_blacklist"
-
     # Add some email addresses to the blacklist
     spam_emails = ["spam1@example.com", "spam2@example.com", "badactor@example.com"]
 
     print("Adding spam emails to blacklist...")
     for email in spam_emails:
-        if bloom.add(filter_key, email):
+        if bloom.add(email):
             print(f"Added {email} to blacklist")
 
     # Check if emails exist in the blacklist
@@ -32,7 +30,7 @@ def main():
 
     print("\nChecking emails against blacklist...")
     for email in test_emails:
-        result = bloom.contains(filter_key, email)
+        result = bloom.contains(email)
         status = "might be" if result else "is not"
         print(f"Email {email} {status} in the blacklist")
 
@@ -42,7 +40,7 @@ def main():
 
     # Clear the Bloom filter
     print("\nClearing the Bloom filter...")
-    if bloom.clear(filter_key):
+    if bloom.clear():
         print("Bloom filter cleared successfully")
 
 
