@@ -3,11 +3,10 @@ from redis_data_structures import Stack
 
 def demonstrate_stack():
     # Initialize stack
-    stack = Stack(host="localhost", port=6379, db=0)
-    stack_key = "undo_stack"
+    stack = Stack(key="undo_stack")
 
     # Clear any existing data
-    stack.clear(stack_key)
+    stack.clear()
 
     print("=== Stack Example (LIFO) ===")
 
@@ -16,20 +15,20 @@ def demonstrate_stack():
     operations = ["Add paragraph 1", "Add paragraph 2", "Delete paragraph 1", "Add paragraph 3"]
 
     for operation in operations:
-        stack.push(stack_key, operation)
+        stack.push(operation)
         print(f"Performed operation: {operation}")
 
-    print(f"\nStack size: {stack.size(stack_key)}")
+    print(f"\nStack size: {stack.size()}")
 
     # Performing undo operations
     print("\nPerforming undo operations...")
     undo_count = 3
     for _i in range(undo_count):
-        if stack.size(stack_key) > 0:
-            operation = stack.pop(stack_key)
+        if stack.size() > 0:
+            operation = stack.pop()
             print(f"Undoing: {operation}")
 
-    print(f"\nRemaining operations in stack: {stack.size(stack_key)}")
+    print(f"\nRemaining operations in stack: {stack.size()}")
 
 
 if __name__ == "__main__":
